intelmq.bots.experts.domain_suffix package — intelmq 2.3.3.alpha1 documentation

# intelmq.bots.experts.domain_suffix package

## Submodules

## intelmq.bots.experts.domain_suffix.expert module

The library publicsuffixlist will be used if installed, otherwise our own internal fallback is used.

`intelmq.bots.experts.domain_suffix.expert.` `BOT`

  alias of `intelmq.bots.experts.domain_suffix.expert.DomainSuffixExpertBot`

class `intelmq.bots.experts.domain_suffix.expert.` `DomainSuffixExpertBot`(bot_id: str, start: bool = False, sighup_event=None, disable_multithreading: Optional[bool] = None)

  Bases: `intelmq.lib.bot.Bot`

  `init`()
  `process`()
  `suffixes` = {}

## intelmq.bots.experts.domain_suffix.lib module

A custom public suffix implementation Only works with punycode, not unicode, as intelmq only uses the first representation.

class `intelmq.bots.experts.domain_suffix.lib.` `PublicSuffixList`(source, only_icann=None)

  Bases: `object`

  `publicsuffix`(domain)

## Module contents